@@ -277,7 +277,11 @@ def create_plot_histograms(
 
     all_hists = {}
 
-    for path in tqdm(calib_sample["files"], leave=False, desc="Processing files"):
+    for path in (
+        tqdm(calib_sample["files"], leave=False, desc="Processing files")
+        if sys.stderr.isatty()  # Use tqdm only when running interactively
+        else calib_sample["files"]
+    ):
         df = pid_data.root_to_dataframe(
             path, tree_paths, list(branch_names.values()), True
         )
